from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *

#the following typedef cannot be wrapped as is
TColStd_Array2OfBoolean = NewType('TColStd_Array2OfBoolean', Any)
#the following typedef cannot be wrapped as is
TColStd_Array2OfCharacter = NewType('TColStd_Array2OfCharacter', Any)
#the following typedef cannot be wrapped as is
TColStd_Array2OfInteger = NewType('TColStd_Array2OfInteger', Any)
#the following typedef cannot be wrapped as is
TColStd_Array2OfReal = NewType('TColStd_Array2OfReal', Any)
#the following typedef cannot be wrapped as is
TColStd_Array2OfTransient = NewType('TColStd_Array2OfTransient', Any)
#the following typedef cannot be wrapped as is
TColStd_IndexedDataMapOfStringString = NewType('TColStd_IndexedDataMapOfStringString', Any)
#the following typedef cannot be wrapped as is
TColStd_IndexedDataMapOfTransientTransient = NewType('TColStd_IndexedDataMapOfTransientTransient', Any)
#the following typedef cannot be wrapped as is
TColStd_IndexedMapOfInteger = NewType('TColStd_IndexedMapOfInteger', Any)
#the following typedef cannot be wrapped as is
TColStd_IndexedMapOfReal = NewType('TColStd_IndexedMapOfReal', Any)
#the following typedef cannot be wrapped as is
TColStd_IndexedMapOfTransient = NewType('TColStd_IndexedMapOfTransient', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIntegerHasher = NewType('TColStd_MapIntegerHasher', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIteratorOfMapOfAsciiString = NewType('TColStd_MapIteratorOfMapOfAsciiString', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIteratorOfMapOfInteger = NewType('TColStd_MapIteratorOfMapOfInteger', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIteratorOfMapOfReal = NewType('TColStd_MapIteratorOfMapOfReal', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIteratorOfMapOfTransient = NewType('TColStd_MapIteratorOfMapOfTransient', Any)
#the following typedef cannot be wrapped as is
TColStd_MapIteratorOfPackedMapOfInteger = NewType('TColStd_MapIteratorOfPackedMapOfInteger', Any)
#the following typedef cannot be wrapped as is
TColStd_MapOfAsciiString = NewType('TColStd_MapOfAsciiString', Any)
#the following typedef cannot be wrapped as is
TColStd_MapOfInteger = NewType('TColStd_MapOfInteger', Any)
#the following typedef cannot be wrapped as is
TColStd_MapOfReal = NewType('TColStd_MapOfReal', Any)
#the following typedef cannot be wrapped as is
TColStd_MapOfTransient = NewType('TColStd_MapOfTransient', Any)
#the following typedef cannot be wrapped as is
TColStd_MapRealHasher = NewType('TColStd_MapRealHasher', Any)
#the following typedef cannot be wrapped as is
TColStd_MapTransientHasher = NewType('TColStd_MapTransientHasher', Any)

class TColStd_Array1OfAsciiString:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TCollection_AsciiString: ...
    def __setitem__(self, index: int, value: TCollection_AsciiString) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TCollection_AsciiString]: ...
    def next(self) -> TCollection_AsciiString: ...
    __next__ = next
    def Init(self, theValue: TCollection_AsciiString) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TCollection_AsciiString: ...
    def Last(self) -> TCollection_AsciiString: ...
    def Value(self, theIndex: int) -> TCollection_AsciiString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_AsciiString) -> None: ...

class TColStd_Array1OfBoolean:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> bool: ...
    def __setitem__(self, index: int, value: bool) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[bool]: ...
    def next(self) -> bool: ...
    __next__ = next
    def Init(self, theValue: bool) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> bool: ...
    def Last(self) -> bool: ...
    def Value(self, theIndex: int) -> bool: ...
    def SetValue(self, theIndex: int, theValue: bool) -> None: ...

class TColStd_Array1OfByte:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> str: ...
    def __setitem__(self, index: int, value: str) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[str]: ...
    def next(self) -> str: ...
    __next__ = next
    def Init(self, theValue: str) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> str: ...
    def Last(self) -> str: ...
    def Value(self, theIndex: int) -> str: ...
    def SetValue(self, theIndex: int, theValue: str) -> None: ...

class TColStd_Array1OfCharacter:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> str: ...
    def __setitem__(self, index: int, value: str) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[str]: ...
    def next(self) -> str: ...
    __next__ = next
    def Init(self, theValue: str) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> str: ...
    def Last(self) -> str: ...
    def Value(self, theIndex: int) -> str: ...
    def SetValue(self, theIndex: int, theValue: str) -> None: ...

class TColStd_Array1OfExtendedString:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TCollection_ExtendedString: ...
    def __setitem__(self, index: int, value: TCollection_ExtendedString) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TCollection_ExtendedString]: ...
    def next(self) -> TCollection_ExtendedString: ...
    __next__ = next
    def Init(self, theValue: TCollection_ExtendedString) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TCollection_ExtendedString: ...
    def Last(self) -> TCollection_ExtendedString: ...
    def Value(self, theIndex: int) -> TCollection_ExtendedString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_ExtendedString) -> None: ...

class TColStd_Array1OfInteger:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> int: ...
    def __setitem__(self, index: int, value: int) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[int]: ...
    def next(self) -> int: ...
    __next__ = next
    def Init(self, theValue: int) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> int: ...
    def Last(self) -> int: ...
    def Value(self, theIndex: int) -> int: ...
    def SetValue(self, theIndex: int, theValue: int) -> None: ...

class TColStd_Array1OfListOfInteger:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TColStd_ListOfInteger: ...
    def __setitem__(self, index: int, value: TColStd_ListOfInteger) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TColStd_ListOfInteger]: ...
    def next(self) -> TColStd_ListOfInteger: ...
    __next__ = next
    def Init(self, theValue: TColStd_ListOfInteger) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TColStd_ListOfInteger: ...
    def Last(self) -> TColStd_ListOfInteger: ...
    def Value(self, theIndex: int) -> TColStd_ListOfInteger: ...
    def SetValue(self, theIndex: int, theValue: TColStd_ListOfInteger) -> None: ...

class TColStd_Array1OfReal:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> float: ...
    def __setitem__(self, index: int, value: float) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[float]: ...
    def next(self) -> float: ...
    __next__ = next
    def Init(self, theValue: float) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> float: ...
    def Last(self) -> float: ...
    def Value(self, theIndex: int) -> float: ...
    def SetValue(self, theIndex: int, theValue: float) -> None: ...

class TColStd_Array1OfTransient:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColStd_ListOfAsciiString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TCollection_AsciiString: ...
    def Last(self) -> TCollection_AsciiString: ...
    def Append(self, theItem: TCollection_AsciiString) -> TCollection_AsciiString: ...
    def Prepend(self, theItem: TCollection_AsciiString) -> TCollection_AsciiString: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TCollection_AsciiString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_AsciiString) -> None: ...

class TColStd_ListOfInteger:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> int: ...
    def Last(self) -> int: ...
    def Append(self, theItem: int) -> int: ...
    def Prepend(self, theItem: int) -> int: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> int: ...
    def SetValue(self, theIndex: int, theValue: int) -> None: ...

class TColStd_ListOfReal:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> float: ...
    def Last(self) -> float: ...
    def Append(self, theItem: float) -> float: ...
    def Prepend(self, theItem: float) -> float: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> float: ...
    def SetValue(self, theIndex: int, theValue: float) -> None: ...

class TColStd_ListOfTransient:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColStd_SequenceOfAddress:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> None: ...
    def Last(self) -> None: ...
    def Length(self) -> int: ...
    def Append(self, theItem: None) -> None: ...
    def Prepend(self, theItem: None) -> None: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> None: ...
    def SetValue(self, theIndex: int, theValue: None) -> None: ...

class TColStd_SequenceOfAsciiString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TCollection_AsciiString: ...
    def Last(self) -> TCollection_AsciiString: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TCollection_AsciiString) -> TCollection_AsciiString: ...
    def Prepend(self, theItem: TCollection_AsciiString) -> TCollection_AsciiString: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TCollection_AsciiString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_AsciiString) -> None: ...

class TColStd_SequenceOfBoolean:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> bool: ...
    def Last(self) -> bool: ...
    def Length(self) -> int: ...
    def Append(self, theItem: bool) -> bool: ...
    def Prepend(self, theItem: bool) -> bool: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> bool: ...
    def SetValue(self, theIndex: int, theValue: bool) -> None: ...

class TColStd_SequenceOfExtendedString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TCollection_ExtendedString: ...
    def Last(self) -> TCollection_ExtendedString: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
    def Prepend(self, theItem: TCollection_ExtendedString) -> TCollection_ExtendedString: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TCollection_ExtendedString: ...
    def SetValue(self, theIndex: int, theValue: TCollection_ExtendedString) -> None: ...

class TColStd_SequenceOfHAsciiString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColStd_SequenceOfHExtendedString:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColStd_SequenceOfInteger:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> int: ...
    def Last(self) -> int: ...
    def Length(self) -> int: ...
    def Append(self, theItem: int) -> int: ...
    def Prepend(self, theItem: int) -> int: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> int: ...
    def SetValue(self, theIndex: int, theValue: int) -> None: ...

class TColStd_SequenceOfReal:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> float: ...
    def Last(self) -> float: ...
    def Length(self) -> int: ...
    def Append(self, theItem: float) -> float: ...
    def Prepend(self, theItem: float) -> float: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> float: ...
    def SetValue(self, theIndex: int, theValue: float) -> None: ...

class TColStd_SequenceOfTransient:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class TColStd_HPackedMapOfInteger(Standard_Transient):
	@overload
	def __init__(self, NbBuckets: Optional[int] = 1) -> None: ...
	@overload
	def __init__(self, theOther: TColStd_PackedMapOfInteger) -> None: ...
	def ChangeMap(self) -> TColStd_PackedMapOfInteger: ...
	def Map(self) -> TColStd_PackedMapOfInteger: ...

# harray1 classes

class TColStd_HArray1OfExtendedString(TColStd_Array1OfExtendedString, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfExtendedString: ...


class TColStd_HArray1OfCharacter(TColStd_Array1OfCharacter, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfCharacter: ...


class TColStd_HArray1OfBoolean(TColStd_Array1OfBoolean, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfBoolean: ...


class TColStd_HArray1OfAsciiString(TColStd_Array1OfAsciiString, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfAsciiString: ...


class TColStd_HArray1OfReal(TColStd_Array1OfReal, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfReal: ...


class TColStd_HArray1OfInteger(TColStd_Array1OfInteger, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfInteger: ...


class TColStd_HArray1OfListOfInteger(TColStd_Array1OfListOfInteger, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfListOfInteger: ...


class TColStd_HArray1OfTransient(TColStd_Array1OfTransient, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfTransient: ...


class TColStd_HArray1OfByte(TColStd_Array1OfByte, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TColStd_Array1OfByte: ...

# harray2 classes

class TColStd_HArray2OfBoolean(TColStd_Array2OfBoolean, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TColStd_Array2OfBoolean) -> None: ...
    def Array2(self) -> TColStd_Array2OfBoolean: ...


class TColStd_HArray2OfTransient(TColStd_Array2OfTransient, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TColStd_Array2OfTransient) -> None: ...
    def Array2(self) -> TColStd_Array2OfTransient: ...


class TColStd_HArray2OfReal(TColStd_Array2OfReal, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TColStd_Array2OfReal) -> None: ...
    def Array2(self) -> TColStd_Array2OfReal: ...


class TColStd_HArray2OfInteger(TColStd_Array2OfInteger, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TColStd_Array2OfInteger) -> None: ...
    def Array2(self) -> TColStd_Array2OfInteger: ...


class TColStd_HArray2OfCharacter(TColStd_Array2OfCharacter, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TColStd_Array2OfCharacter) -> None: ...
    def Array2(self) -> TColStd_Array2OfCharacter: ...

# hsequence classes

class TColStd_HSequenceOfHAsciiString(TColStd_SequenceOfHAsciiString, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfHAsciiString) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfHAsciiString: ...
    def Append(self, theSequence: TColStd_SequenceOfHAsciiString) -> None: ...


class TColStd_HSequenceOfTransient(TColStd_SequenceOfTransient, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfTransient) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfTransient: ...
    def Append(self, theSequence: TColStd_SequenceOfTransient) -> None: ...


class TColStd_HSequenceOfAsciiString(TColStd_SequenceOfAsciiString, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfAsciiString) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfAsciiString: ...
    def Append(self, theSequence: TColStd_SequenceOfAsciiString) -> None: ...


class TColStd_HSequenceOfHExtendedString(TColStd_SequenceOfHExtendedString, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfHExtendedString) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfHExtendedString: ...
    def Append(self, theSequence: TColStd_SequenceOfHExtendedString) -> None: ...


class TColStd_HSequenceOfInteger(TColStd_SequenceOfInteger, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfInteger) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfInteger: ...
    def Append(self, theSequence: TColStd_SequenceOfInteger) -> None: ...


class TColStd_HSequenceOfExtendedString(TColStd_SequenceOfExtendedString, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfExtendedString) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfExtendedString: ...
    def Append(self, theSequence: TColStd_SequenceOfExtendedString) -> None: ...


class TColStd_HSequenceOfReal(TColStd_SequenceOfReal, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TColStd_SequenceOfReal) -> None: ...
    def Sequence(self) -> TColStd_SequenceOfReal: ...
    def Append(self, theSequence: TColStd_SequenceOfReal) -> None: ...





from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor2d import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *


class geom2dadaptor:
	@staticmethod
	def MakeCurve(HC: Adaptor2d_Curve2d) -> Geom2d_Curve: ...

class Geom2dAdaptor_Curve(Adaptor2d_Curve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Curve) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Curve, UFirst: float, ULast: float) -> None: ...
	def BSpline(self) -> Geom2d_BSplineCurve: ...
	def Bezier(self) -> Geom2d_BezierCurve: ...
	def Circle(self) -> gp_Circ2d: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Curve(self) -> Geom2d_Curve: ...
	def D0(self, U: float, P: gp_Pnt2d) -> None: ...
	def D1(self, U: float, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	def D2(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	def D3(self, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec2d: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips2d: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr2d: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin2d: ...
	@overload
	def Load(self, C: Geom2d_Curve) -> None: ...
	@overload
	def Load(self, C: Geom2d_Curve, UFirst: float, ULast: float) -> None: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def NbSamples(self) -> int: ...
	def Parabola(self) -> gp_Parab2d: ...
	def Period(self) -> float: ...
	def Reset(self) -> None: ...
	def Resolution(self, Ruv: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor2d_HCurve2d: ...
	def Value(self, U: float) -> gp_Pnt2d: ...

class Geom2dAdaptor_GHCurve(Adaptor2d_HCurve2d):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Geom2dAdaptor_Curve) -> None: ...
	def ChangeCurve2d(self) -> Geom2dAdaptor_Curve: ...
	def Curve2d(self) -> Adaptor2d_Curve2d: ...
	def Set(self, C: Geom2dAdaptor_Curve) -> None: ...

class Geom2dAdaptor_HCurve(Geom2dAdaptor_GHCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, AS: Geom2dAdaptor_Curve) -> None: ...
	@overload
	def __init__(self, S: Geom2d_Curve) -> None: ...
	@overload
	def __init__(self, S: Geom2d_Curve, UFirst: float, ULast: float) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

geom2dadaptor_MakeCurve = geom2dadaptor.MakeCurve



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
IGESCAFControl module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_igescafcontrol.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _IGESCAFControl
else:
    import _IGESCAFControl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _IGESCAFControl.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _IGESCAFControl.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _IGESCAFControl.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _IGESCAFControl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESCAFControl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _IGESCAFControl.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _IGESCAFControl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _IGESCAFControl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _IGESCAFControl:
_IGESCAFControl.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _IGESCAFControl.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Quantity
import OCC.Core.TCollection
import OCC.Core.IGESControl
import OCC.Core.Transfer
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.Interface
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IGESToBRep
import OCC.Core.IGESData
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom
import OCC.Core.TopTools
import OCC.Core.Geom2d
import OCC.Core.XSControl
import OCC.Core.IFSelect
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *



class igescafcontrol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def DecodeColor(*args) -> "Quantity_Color":
        r"""
        Provides a tool for writing iges file converts iges color index to cascade color.

        Parameters
        ----------
        col: int

        Returns
        -------
        Quantity_Color

        """
        return _IGESCAFControl.igescafcontrol_DecodeColor(*args)

    @staticmethod
    def EncodeColor(*args) -> "Standard_Integer":
        r"""
        Tries to convert cascade color to iges color index if no corresponding color defined in iges, returns 0.

        Parameters
        ----------
        col: Quantity_Color

        Returns
        -------
        int

        """
        return _IGESCAFControl.igescafcontrol_EncodeColor(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _IGESCAFControl.igescafcontrol_swiginit(self, _IGESCAFControl.new_igescafcontrol())
    __swig_destroy__ = _IGESCAFControl.delete_igescafcontrol

# Register igescafcontrol in _IGESCAFControl:
_IGESCAFControl.igescafcontrol_swigregister(igescafcontrol)

def igescafcontrol_DecodeColor(*args) -> "Quantity_Color":
    r"""
    Provides a tool for writing iges file converts iges color index to cascade color.

    Parameters
    ----------
    col: int

    Returns
    -------
    Quantity_Color

    """
    return _IGESCAFControl.igescafcontrol_DecodeColor(*args)

def igescafcontrol_EncodeColor(*args) -> "Standard_Integer":
    r"""
    Tries to convert cascade color to iges color index if no corresponding color defined in iges, returns 0.

    Parameters
    ----------
    col: Quantity_Color

    Returns
    -------
    int

    """
    return _IGESCAFControl.igescafcontrol_EncodeColor(*args)

class IGESCAFControl_Reader(OCC.Core.IGESControl.IGESControl_Reader):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a reader with an empty iges model and sets colormode, layermode and namemode to standard_true.

        Returns
        -------
        None
        Creates a reader tool and attaches it to an already existing session clears the session if it was not yet set for iges.

        Parameters
        ----------
        theWS: XSControl_WorkSession
        FromScratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _IGESCAFControl.IGESCAFControl_Reader_swiginit(self, _IGESCAFControl.new_IGESCAFControl_Reader(*args))

    def GetColorMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetColorMode(self, *args)

    def GetLayerMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetLayerMode(self, *args)

    def GetNameMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_GetNameMode(self, *args)

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        theFileName: TCollection_AsciiString
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Translate iges file given by filename into the document return true if succeeded, and false in case of fail.

        Parameters
        ----------
        theFileName: char *
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_Perform(self, *args)

    def SetColorMode(self, *args) -> "void":
        r"""
        Set colormode for indicate read colors or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetColorMode(self, *args)

    def SetLayerMode(self, *args) -> "void":
        r"""
        Set layermode for indicate read layers or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetLayerMode(self, *args)

    def SetNameMode(self, *args) -> "void":
        r"""
        Set namemode for indicate read name or not.

        Parameters
        ----------
        theMode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Reader_SetNameMode(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Translates currently loaded iges file into the document returns true if succeeded, and false in case of fail.

        Parameters
        ----------
        theDoc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Reader_Transfer(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESCAFControl.delete_IGESCAFControl_Reader

# Register IGESCAFControl_Reader in _IGESCAFControl:
_IGESCAFControl.IGESCAFControl_Reader_swigregister(IGESCAFControl_Reader)

class IGESCAFControl_Writer(OCC.Core.IGESControl.IGESControl_Writer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a writer with an empty iges model and sets colormode, layermode and namemode to standard_true.

        Returns
        -------
        None
        Creates a reader tool and attaches it to an already existing session clears the session if it was not yet set for iges.

        Parameters
        ----------
        WS: XSControl_WorkSession
        scratch: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _IGESCAFControl.IGESCAFControl_Writer_swiginit(self, _IGESCAFControl.new_IGESCAFControl_Writer(*args))

    def GetColorMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetColorMode(self, *args)

    def GetLayerMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetLayerMode(self, *args)

    def GetNameMode(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_GetNameMode(self, *args)

    def Perform(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        doc: TDocStd_Document
        filename: TCollection_AsciiString
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers a document and writes it to a iges file returns true if translation is ok.

        Parameters
        ----------
        doc: TDocStd_Document
        filename: char *
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_Perform(self, *args)

    def SetColorMode(self, *args) -> "void":
        r"""
        Set colormode for indicate write colors or not.

        Parameters
        ----------
        colormode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetColorMode(self, *args)

    def SetLayerMode(self, *args) -> "void":
        r"""
        Set layermode for indicate write layers or not.

        Parameters
        ----------
        layermode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetLayerMode(self, *args)

    def SetNameMode(self, *args) -> "void":
        r"""
        Set namemode for indicate write name or not.

        Parameters
        ----------
        namemode: bool

        Returns
        -------
        None

        """
        return _IGESCAFControl.IGESCAFControl_Writer_SetNameMode(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Transfers a document to a iges model returns true if translation is ok.

        Parameters
        ----------
        doc: TDocStd_Document
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers labels to a iges model returns true if translation is ok.

        Parameters
        ----------
        labels: TDF_LabelSequence
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool
        Transfers label to a iges model returns true if translation is ok.

        Parameters
        ----------
        label: TDF_Label
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _IGESCAFControl.IGESCAFControl_Writer_Transfer(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _IGESCAFControl.delete_IGESCAFControl_Writer

# Register IGESCAFControl_Writer in _IGESCAFControl:
_IGESCAFControl.IGESCAFControl_Writer_swigregister(IGESCAFControl_Writer)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *


class AppBlend_Approx:
	def Curve2d(self, Index: int, TPoles: TColgp_Array1OfPnt2d, TKnots: TColStd_Array1OfReal, TMults: TColStd_Array1OfInteger) -> None: ...
	def Curve2dPoles(self, Index: int) -> TColgp_Array1OfPnt2d: ...
	def Curves2dDegree(self) -> int: ...
	def Curves2dKnots(self) -> TColStd_Array1OfReal: ...
	def Curves2dMults(self) -> TColStd_Array1OfInteger: ...
	def Curves2dShape(self) -> Tuple[int, int, int]: ...
	def IsDone(self) -> bool: ...
	def NbCurves2d(self) -> int: ...
	def SurfPoles(self) -> TColgp_Array2OfPnt: ...
	def SurfShape(self) -> Tuple[int, int, int, int, int, int]: ...
	def SurfUKnots(self) -> TColStd_Array1OfReal: ...
	def SurfUMults(self) -> TColStd_Array1OfInteger: ...
	def SurfVKnots(self) -> TColStd_Array1OfReal: ...
	def SurfVMults(self) -> TColStd_Array1OfInteger: ...
	def SurfWeights(self) -> TColStd_Array2OfReal: ...
	def Surface(self, TPoles: TColgp_Array2OfPnt, TWeights: TColStd_Array2OfReal, TUKnots: TColStd_Array1OfReal, TVKnots: TColStd_Array1OfReal, TUMults: TColStd_Array1OfInteger, TVMults: TColStd_Array1OfInteger) -> None: ...
	def TolCurveOnSurf(self, Index: int) -> float: ...
	def TolReached(self) -> Tuple[float, float]: ...
	def UDegree(self) -> int: ...
	def VDegree(self) -> int: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
HLRTopoBRep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_hlrtopobrep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _HLRTopoBRep
else:
    import _HLRTopoBRep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _HLRTopoBRep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _HLRTopoBRep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _HLRTopoBRep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _HLRTopoBRep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _HLRTopoBRep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _HLRTopoBRep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _HLRTopoBRep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _HLRTopoBRep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _HLRTopoBRep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _HLRTopoBRep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _HLRTopoBRep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _HLRTopoBRep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _HLRTopoBRep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _HLRTopoBRep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _HLRTopoBRep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _HLRTopoBRep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _HLRTopoBRep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _HLRTopoBRep:
_HLRTopoBRep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _HLRTopoBRep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Contap
import OCC.Core.math
import OCC.Core.IntSurf
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.BRepTopAdaptor
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.TopTools
import OCC.Core.HLRAlgo

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_HLRTopoBRep_OutLiner_Create() -> "opencascade::handle< HLRTopoBRep_OutLiner >":
    return _HLRTopoBRep.Handle_HLRTopoBRep_OutLiner_Create()

def Handle_HLRTopoBRep_OutLiner_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< HLRTopoBRep_OutLiner >":
    return _HLRTopoBRep.Handle_HLRTopoBRep_OutLiner_DownCast(t)

def Handle_HLRTopoBRep_OutLiner_IsNull(t: "opencascade::handle< HLRTopoBRep_OutLiner > const &") -> "bool":
    return _HLRTopoBRep.Handle_HLRTopoBRep_OutLiner_IsNull(t)
class HLRTopoBRep_DataMapOfShapeFaceData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_cend(self)

    def __init__(self, *args):
        _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_DataMapOfShapeFaceData(*args))

    def Exchange(self, theOther: "HLRTopoBRep_DataMapOfShapeFaceData") -> "void":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Exchange(self, theOther)

    def Assign(self, theOther: "HLRTopoBRep_DataMapOfShapeFaceData") -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher > &":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Assign(self, theOther)

    def Set(self, theOther: "HLRTopoBRep_DataMapOfShapeFaceData") -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_FaceData,TopTools_ShapeMapHasher > &":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "HLRTopoBRep_FaceData") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "HLRTopoBRep_FaceData") -> "HLRTopoBRep_FaceData *":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_FaceData const *":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_FaceData *":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_FaceData &":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_ChangeFind(self, theKey)

    def __call__(self, *args) -> "HLRTopoBRep_FaceData &":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Clear(self, *args)
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_DataMapOfShapeFaceData

    def Size(self) -> "Standard_Integer":
        return _HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_Size(self)

# Register HLRTopoBRep_DataMapOfShapeFaceData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_DataMapOfShapeFaceData_swigregister(HLRTopoBRep_DataMapOfShapeFaceData)

class HLRTopoBRep_ListIteratorOfListOfVData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_ListIteratorOfListOfVData(*args))

    def More(self) -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_More(self)

    def Next(self) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_Next(self)

    def Value(self) -> "HLRTopoBRep_VData const &":
        return _HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_Value(self)

    def ChangeValue(self) -> "HLRTopoBRep_VData &":
        return _HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_ChangeValue(self)
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_ListIteratorOfListOfVData

# Register HLRTopoBRep_ListIteratorOfListOfVData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_ListIteratorOfListOfVData_swigregister(HLRTopoBRep_ListIteratorOfListOfVData)

class HLRTopoBRep_ListOfVData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< HLRTopoBRep_VData >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_begin(self)

    def end(self) -> "NCollection_List< HLRTopoBRep_VData >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_end(self)

    def cbegin(self) -> "NCollection_List< HLRTopoBRep_VData >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_cbegin(self)

    def cend(self) -> "NCollection_List< HLRTopoBRep_VData >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_cend(self)

    def __init__(self, *args):
        _HLRTopoBRep.HLRTopoBRep_ListOfVData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_ListOfVData(*args))

    def Size(self) -> "Standard_Integer":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Size(self)

    def Assign(self, theOther: "HLRTopoBRep_ListOfVData") -> "NCollection_List< HLRTopoBRep_VData > &":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Assign(self, theOther)

    def Set(self, theOther: "HLRTopoBRep_ListOfVData") -> "NCollection_List< HLRTopoBRep_VData > &":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Set(self, theOther)

    def Clear(self, theAllocator: "IntSurf_Allocator"=0) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Clear(self, theAllocator)

    def First(self) -> "HLRTopoBRep_VData const &":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_First(self)

    def Last(self) -> "HLRTopoBRep_VData const &":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Last(self)

    def Append(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_RemoveFirst(self)

    def Remove(self, theIter: "HLRTopoBRep_ListIteratorOfListOfVData") -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_ListOfVData_Reverse(self)
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_ListOfVData

    def __len__(self):
        return self.Size()


# Register HLRTopoBRep_ListOfVData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_ListOfVData_swigregister(HLRTopoBRep_ListOfVData)

class HLRTopoBRep_MapOfShapeListOfVData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_begin(self)

    def end(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher >::iterator":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_end(self)

    def cbegin(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher >::const_iterator":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_cend(self)

    def __init__(self, *args):
        _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_MapOfShapeListOfVData(*args))

    def Exchange(self, theOther: "HLRTopoBRep_MapOfShapeListOfVData") -> "void":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Exchange(self, theOther)

    def Assign(self, theOther: "HLRTopoBRep_MapOfShapeListOfVData") -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher > &":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Assign(self, theOther)

    def Set(self, theOther: "HLRTopoBRep_MapOfShapeListOfVData") -> "NCollection_DataMap< TopoDS_Shape,HLRTopoBRep_ListOfVData,TopTools_ShapeMapHasher > &":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_ReSize(self, N)

    def Bind(self, theKey: "TopoDS_Shape", theItem: "HLRTopoBRep_ListOfVData") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TopoDS_Shape", theItem: "HLRTopoBRep_ListOfVData") -> "HLRTopoBRep_ListOfVData *":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_IsBound(self, theKey)

    def UnBind(self, theKey: "TopoDS_Shape") -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_UnBind(self, theKey)

    def Seek(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_ListOfVData const *":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Find(self, *args)

    def ChangeSeek(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_ListOfVData *":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TopoDS_Shape") -> "HLRTopoBRep_ListOfVData &":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_ChangeFind(self, theKey)

    def __call__(self, *args) -> "HLRTopoBRep_ListOfVData &":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Clear(self, *args)
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_MapOfShapeListOfVData

    def Size(self) -> "Standard_Integer":
        return _HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_Size(self)

# Register HLRTopoBRep_MapOfShapeListOfVData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_MapOfShapeListOfVData_swigregister(HLRTopoBRep_MapOfShapeListOfVData)

class HLRTopoBRep_DSFiller(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Insert(*args) -> "void":
        r"""
        Stores in <ds> the outlines of <s> using the current outliner and stores the isolines in <ds> using a hatcher.

        Parameters
        ----------
        S: TopoDS_Shape
        FO: Contap_Contour
        DS: HLRTopoBRep_Data
        MST: BRepTopAdaptor_MapOfShapeTool
        nbIso: int

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_DSFiller_Insert(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _HLRTopoBRep.HLRTopoBRep_DSFiller_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_DSFiller())
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_DSFiller

# Register HLRTopoBRep_DSFiller in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_DSFiller_swigregister(HLRTopoBRep_DSFiller)

def HLRTopoBRep_DSFiller_Insert(*args) -> "void":
    r"""
    Stores in <ds> the outlines of <s> using the current outliner and stores the isolines in <ds> using a hatcher.

    Parameters
    ----------
    S: TopoDS_Shape
    FO: Contap_Contour
    DS: HLRTopoBRep_Data
    MST: BRepTopAdaptor_MapOfShapeTool
    nbIso: int

    Returns
    -------
    None

    """
    return _HLRTopoBRep.HLRTopoBRep_DSFiller_Insert(*args)

class HLRTopoBRep_Data(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _HLRTopoBRep.HLRTopoBRep_Data_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_Data(*args))

    def AddIntL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddIntL(self, *args)

    def AddIntV(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddIntV(self, *args)

    def AddIsoL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddIsoL(self, *args)

    def AddOldS(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        NewS: TopoDS_Shape
        OldS: TopoDS_Shape

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddOldS(self, *args)

    def AddOutL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddOutL(self, *args)

    def AddOutV(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddOutV(self, *args)

    def AddSplE(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_AddSplE(self, *args)

    def Append(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        V: TopoDS_Vertex
        P: float

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Append(self, *args)

    def Clean(self, *args) -> "void":
        r"""
        Clear of all the data not needed during and after the hiding process.

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Clean(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Clear of all the maps.

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Clear(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Edge(self, *args)

    def EdgeHasSplE(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge is split.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_EdgeHasSplE(self, *args)

    def EdgeSplE(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of the edges.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_EdgeSplE(self, *args)

    def FaceHasIntL(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face has internal outline.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceHasIntL(self, *args)

    def FaceHasIsoL(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face has isolines.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceHasIsoL(self, *args)

    def FaceHasOutL(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the face has outlines on restriction.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceHasOutL(self, *args)

    def FaceIntL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of the internal outlines.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceIntL(self, *args)

    def FaceIsoL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of the isolines.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceIsoL(self, *args)

    def FaceOutL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Returns the list of the outlines on restriction.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_FaceOutL(self, *args)

    def InitEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_InitEdge(self, *args)

    def InitVertex(self, *args) -> "void":
        r"""
        Start an iteration on the vertices of e.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_InitVertex(self, *args)

    def InsertBefore(self, *args) -> "void":
        r"""
        Insert before the current position.

        Parameters
        ----------
        V: TopoDS_Vertex
        P: float

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_InsertBefore(self, *args)

    def IsIntLFaceEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsIntLFaceEdge(self, *args)

    def IsIntV(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if v is an internal outline vertex.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsIntV(self, *args)

    def IsIsoLFaceEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsIsoLFaceEdge(self, *args)

    def IsOutLFaceEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsOutLFaceEdge(self, *args)

    def IsOutV(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if v is an outline vertex on a restriction.

        Parameters
        ----------
        V: TopoDS_Vertex

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsOutV(self, *args)

    def IsSplEEdgeEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        E1: TopoDS_Edge
        E2: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_IsSplEEdgeEdge(self, *args)

    def MoreEdge(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_MoreEdge(self, *args)

    def MoreVertex(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_MoreVertex(self, *args)

    def NewSOldS(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        New: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_NewSOldS(self, *args)

    def NextEdge(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_NextEdge(self, *args)

    def NextVertex(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_NextVertex(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Parameter(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _HLRTopoBRep.HLRTopoBRep_Data_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_Data

# Register HLRTopoBRep_Data in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_Data_swigregister(HLRTopoBRep_Data)

class HLRTopoBRep_FaceData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _HLRTopoBRep.HLRTopoBRep_FaceData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_FaceData(*args))

    def AddIntL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_AddIntL(self, *args)

    def AddIsoL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_AddIsoL(self, *args)

    def AddOutL(self, *args) -> "TopTools_ListOfShape &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_AddOutL(self, *args)

    def FaceIntL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_FaceIntL(self, *args)

    def FaceIsoL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_FaceIsoL(self, *args)

    def FaceOutL(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        No available documentation.

        Returns
        -------
        TopTools_ListOfShape

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceData_FaceOutL(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_FaceData

# Register HLRTopoBRep_FaceData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_FaceData_swigregister(HLRTopoBRep_FaceData)

class HLRTopoBRep_FaceIsoLiner(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def MakeIsoLine(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        Iso: Geom2d_Line
        V1: TopoDS_Vertex
        V2: TopoDS_Vertex
        U1: float
        U2: float
        Tol: float
        DS: HLRTopoBRep_Data

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_MakeIsoLine(*args)

    @staticmethod
    def MakeVertex(*args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        P: gp_Pnt
        Par: float
        Tol: float
        DS: HLRTopoBRep_Data

        Returns
        -------
        TopoDS_Vertex

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_MakeVertex(*args)

    @staticmethod
    def Perform(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        FI: int
        F: TopoDS_Face
        DS: HLRTopoBRep_Data
        nbIsos: int

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_Perform(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_FaceIsoLiner())
    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_FaceIsoLiner

# Register HLRTopoBRep_FaceIsoLiner in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_swigregister(HLRTopoBRep_FaceIsoLiner)

def HLRTopoBRep_FaceIsoLiner_MakeIsoLine(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    F: TopoDS_Face
    Iso: Geom2d_Line
    V1: TopoDS_Vertex
    V2: TopoDS_Vertex
    U1: float
    U2: float
    Tol: float
    DS: HLRTopoBRep_Data

    Returns
    -------
    None

    """
    return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_MakeIsoLine(*args)

def HLRTopoBRep_FaceIsoLiner_MakeVertex(*args) -> "TopoDS_Vertex":
    r"""
    No available documentation.

    Parameters
    ----------
    E: TopoDS_Edge
    P: gp_Pnt
    Par: float
    Tol: float
    DS: HLRTopoBRep_Data

    Returns
    -------
    TopoDS_Vertex

    """
    return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_MakeVertex(*args)

def HLRTopoBRep_FaceIsoLiner_Perform(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    FI: int
    F: TopoDS_Face
    DS: HLRTopoBRep_Data
    nbIsos: int

    Returns
    -------
    None

    """
    return _HLRTopoBRep.HLRTopoBRep_FaceIsoLiner_Perform(*args)

class HLRTopoBRep_OutLiner(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        OriSh: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        OriS: TopoDS_Shape
        OutS: TopoDS_Shape

        Returns
        -------
        None

        """
        _HLRTopoBRep.HLRTopoBRep_OutLiner_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_OutLiner(*args))

    def DataStructure(self, *args) -> "HLRTopoBRep_Data &":
        r"""
        No available documentation.

        Returns
        -------
        HLRTopoBRep_Data

        """
        return _HLRTopoBRep.HLRTopoBRep_OutLiner_DataStructure(self, *args)

    def Fill(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        P: HLRAlgo_Projector
        MST: BRepTopAdaptor_MapOfShapeTool
        nbIso: int

        Returns
        -------
        None

        """
        return _HLRTopoBRep.HLRTopoBRep_OutLiner_Fill(self, *args)

    def OriginalShape(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        OriS: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRTopoBRep.HLRTopoBRep_OutLiner_OriginalShape(self, *args)

    def OutLinedShape(self, *args) -> "TopoDS_Shape":
        r"""
        No available documentation.

        Parameters
        ----------
        OutS: TopoDS_Shape

        Returns
        -------
        None
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRTopoBRep.HLRTopoBRep_OutLiner_OutLinedShape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_HLRTopoBRep_OutLiner_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_OutLiner

# Register HLRTopoBRep_OutLiner in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_OutLiner_swigregister(HLRTopoBRep_OutLiner)

class HLRTopoBRep_VData(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        P: float
        V: TopoDS_Shape

        Returns
        -------
        None

        """
        _HLRTopoBRep.HLRTopoBRep_VData_swiginit(self, _HLRTopoBRep.new_HLRTopoBRep_VData(*args))

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Returns
        -------
        float

        """
        return _HLRTopoBRep.HLRTopoBRep_VData_Parameter(self, *args)

    def Vertex(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shape

        """
        return _HLRTopoBRep.HLRTopoBRep_VData_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _HLRTopoBRep.delete_HLRTopoBRep_VData

# Register HLRTopoBRep_VData in _HLRTopoBRep:
_HLRTopoBRep.HLRTopoBRep_VData_swigregister(HLRTopoBRep_VData)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
CDF module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_cdf.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _CDF
else:
    import _CDF

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _CDF.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _CDF.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CDF.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _CDF.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _CDF.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _CDF.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _CDF.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _CDF.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _CDF.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _CDF.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CDF.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _CDF.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _CDF.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CDF.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _CDF.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _CDF.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _CDF.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _CDF:
_CDF.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _CDF.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.CDM
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *

CDF_TOA_New = _CDF.CDF_TOA_New
CDF_TOA_Modified = _CDF.CDF_TOA_Modified
CDF_TOA_Unchanged = _CDF.CDF_TOA_Unchanged
CDF_TS_OK = _CDF.CDF_TS_OK
CDF_TS_NoCurrentDocument = _CDF.CDF_TS_NoCurrentDocument
CDF_TS_NoDriver = _CDF.CDF_TS_NoDriver
CDF_TS_NoSubComponentDriver = _CDF.CDF_TS_NoSubComponentDriver
CDF_SCS_Consistent = _CDF.CDF_SCS_Consistent
CDF_SCS_Unconsistent = _CDF.CDF_SCS_Unconsistent
CDF_SCS_Stored = _CDF.CDF_SCS_Stored
CDF_SCS_Modified = _CDF.CDF_SCS_Modified
CDF_SSNS_OK = _CDF.CDF_SSNS_OK
CDF_SSNS_ReplacingAnExistentDocument = _CDF.CDF_SSNS_ReplacingAnExistentDocument
CDF_SSNS_OpenDocument = _CDF.CDF_SSNS_OpenDocument


class CDF_TypeOfActivation(IntEnum):
	CDF_TOA_New = 0
	CDF_TOA_Modified = 1
	CDF_TOA_Unchanged = 2
CDF_TOA_New = CDF_TypeOfActivation.CDF_TOA_New
CDF_TOA_Modified = CDF_TypeOfActivation.CDF_TOA_Modified
CDF_TOA_Unchanged = CDF_TypeOfActivation.CDF_TOA_Unchanged

class CDF_TryStoreStatus(IntEnum):
	CDF_TS_OK = 0
	CDF_TS_NoCurrentDocument = 1
	CDF_TS_NoDriver = 2
	CDF_TS_NoSubComponentDriver = 3
CDF_TS_OK = CDF_TryStoreStatus.CDF_TS_OK
CDF_TS_NoCurrentDocument = CDF_TryStoreStatus.CDF_TS_NoCurrentDocument
CDF_TS_NoDriver = CDF_TryStoreStatus.CDF_TS_NoDriver
CDF_TS_NoSubComponentDriver = CDF_TryStoreStatus.CDF_TS_NoSubComponentDriver

class CDF_SubComponentStatus(IntEnum):
	CDF_SCS_Consistent = 0
	CDF_SCS_Unconsistent = 1
	CDF_SCS_Stored = 2
	CDF_SCS_Modified = 3
CDF_SCS_Consistent = CDF_SubComponentStatus.CDF_SCS_Consistent
CDF_SCS_Unconsistent = CDF_SubComponentStatus.CDF_SCS_Unconsistent
CDF_SCS_Stored = CDF_SubComponentStatus.CDF_SCS_Stored
CDF_SCS_Modified = CDF_SubComponentStatus.CDF_SCS_Modified

class CDF_StoreSetNameStatus(IntEnum):
	CDF_SSNS_OK = 0
	CDF_SSNS_ReplacingAnExistentDocument = 1
	CDF_SSNS_OpenDocument = 2
CDF_SSNS_OK = CDF_StoreSetNameStatus.CDF_SSNS_OK
CDF_SSNS_ReplacingAnExistentDocument = CDF_StoreSetNameStatus.CDF_SSNS_ReplacingAnExistentDocument
CDF_SSNS_OpenDocument = CDF_StoreSetNameStatus.CDF_SSNS_OpenDocument


def Handle_CDF_Application_Create() -> "opencascade::handle< CDF_Application >":
    return _CDF.Handle_CDF_Application_Create()

def Handle_CDF_Application_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_Application >":
    return _CDF.Handle_CDF_Application_DownCast(t)

def Handle_CDF_Application_IsNull(t: "opencascade::handle< CDF_Application > const &") -> "bool":
    return _CDF.Handle_CDF_Application_IsNull(t)

def Handle_CDF_Directory_Create() -> "opencascade::handle< CDF_Directory >":
    return _CDF.Handle_CDF_Directory_Create()

def Handle_CDF_Directory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_Directory >":
    return _CDF.Handle_CDF_Directory_DownCast(t)

def Handle_CDF_Directory_IsNull(t: "opencascade::handle< CDF_Directory > const &") -> "bool":
    return _CDF.Handle_CDF_Directory_IsNull(t)

def Handle_CDF_MetaDataDriver_Create() -> "opencascade::handle< CDF_MetaDataDriver >":
    return _CDF.Handle_CDF_MetaDataDriver_Create()

def Handle_CDF_MetaDataDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_MetaDataDriver >":
    return _CDF.Handle_CDF_MetaDataDriver_DownCast(t)

def Handle_CDF_MetaDataDriver_IsNull(t: "opencascade::handle< CDF_MetaDataDriver > const &") -> "bool":
    return _CDF.Handle_CDF_MetaDataDriver_IsNull(t)

def Handle_CDF_MetaDataDriverFactory_Create() -> "opencascade::handle< CDF_MetaDataDriverFactory >":
    return _CDF.Handle_CDF_MetaDataDriverFactory_Create()

def Handle_CDF_MetaDataDriverFactory_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_MetaDataDriverFactory >":
    return _CDF.Handle_CDF_MetaDataDriverFactory_DownCast(t)

def Handle_CDF_MetaDataDriverFactory_IsNull(t: "opencascade::handle< CDF_MetaDataDriverFactory > const &") -> "bool":
    return _CDF.Handle_CDF_MetaDataDriverFactory_IsNull(t)

def Handle_CDF_StoreList_Create() -> "opencascade::handle< CDF_StoreList >":
    return _CDF.Handle_CDF_StoreList_Create()

def Handle_CDF_StoreList_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_StoreList >":
    return _CDF.Handle_CDF_StoreList_DownCast(t)

def Handle_CDF_StoreList_IsNull(t: "opencascade::handle< CDF_StoreList > const &") -> "bool":
    return _CDF.Handle_CDF_StoreList_IsNull(t)

def Handle_CDF_FWOSDriver_Create() -> "opencascade::handle< CDF_FWOSDriver >":
    return _CDF.Handle_CDF_FWOSDriver_Create()

def Handle_CDF_FWOSDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< CDF_FWOSDriver >":
    return _CDF.Handle_CDF_FWOSDriver_DownCast(t)

def Handle_CDF_FWOSDriver_IsNull(t: "opencascade::handle< CDF_FWOSDriver > const &") -> "bool":
    return _CDF.Handle_CDF_FWOSDriver_IsNull(t)
class CDF_Application(OCC.Core.CDM.CDM_Application):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    myMetaDataDriver = property(_CDF.CDF_Application_myMetaDataDriver_get, _CDF.CDF_Application_myMetaDataDriver_set, doc=r"""myMetaDataDriver : opencascade::handle<(CDF_MetaDataDriver)>""")
    myDirectory = property(_CDF.CDF_Application_myDirectory_get, _CDF.CDF_Application_myDirectory_set, doc=r"""myDirectory : opencascade::handle<(CDF_Directory)>""")

    def CanClose(self, *args) -> "CDM_CanCloseStatus":
        r"""
        No available documentation.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        CDM_CanCloseStatus

        """
        return _CDF.CDF_Application_CanClose(self, *args)

    def CanRetrieve(self, *args) -> "PCDM_ReaderStatus":
        r"""
        No available documentation.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString

        Returns
        -------
        PCDM_ReaderStatus
        No available documentation.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        aVersion: TCollection_ExtendedString

        Returns
        -------
        PCDM_ReaderStatus

        """
        return _CDF.CDF_Application_CanRetrieve(self, *args)

    def Close(self, *args) -> "void":
        r"""
        Removes the document of the current session directory and closes the document;.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _CDF.CDF_Application_Close(self, *args)

    def DefaultFolder(self, *args) -> "Standard_ExtString":
        r"""
        No available documentation.

        Returns
        -------
        Standard_ExtString

        """
        return _CDF.CDF_Application_DefaultFolder(self, *args)

    def Format(self, *args) -> "Standard_Boolean":
        r"""
        Try to retrieve a format directly in the file or in application resource by using extension. returns true if found;.

        Parameters
        ----------
        aFileName: TCollection_ExtendedString
        theFormat: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _CDF.CDF_Application_Format(self, *args)

    def GetRetrieveStatus(self, *args) -> "PCDM_ReaderStatus":
        r"""
        Checks status after retrieve.

        Returns
        -------
        PCDM_ReaderStatus

        """
        return _CDF.CDF_Application_GetRetrieveStatus(self, *args)

    @staticmethod
    def Load(*args) -> "opencascade::handle< CDF_Application >":
        r"""
        Plugs an application. //! open is used - for opening a document that has been created in an application - for opening a document from the database - for opening a document from a file. the open methods always add the document in the session directory and calls the virtual activate method. the document is considered to be opened until close is used. to be storable, a document must be opened by an application since the application resources are needed to store it.

        Parameters
        ----------
        aGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<CDF_Application>

        """
        return _CDF.CDF_Application_Load(*args)

    def MetaDataDriver(self, *args) -> "opencascade::handle< CDF_MetaDataDriver >":
        r"""
        Returns metadatddriver of this application.

        Returns
        -------
        opencascade::handle<CDF_MetaDataDriver>

        """
        return _CDF.CDF_Application_MetaDataDriver(self, *args)

    def Open(self, *args) -> "void":
        r"""
        Puts the document in the current session directory and calls the virtual method activate on it.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _CDF.CDF_Application_Open(self, *args)

    def ReadFromString(self, src: "std::string") -> "void":
        r"""ReadFromString(CDF_Application self, std::string src)"""
        return _CDF.CDF_Application_ReadFromString(self, src)

    def ReaderFromFormat(self, *args) -> "opencascade::handle< PCDM_Reader >":
        r"""
        Returns instance of read driver for specified format. //! default implementation uses plugin mechanism to load reader dynamically. for this to work, application resources should define guid of the plugin as value of [format].retrievalplugin, and 'plugin' resource should define name of plugin library to be loaded as value of [guid].location. plugin library should provide method pluginfactory returning instance of the reader for the same guid (see plugin_macro.hxx). //! in case if reader is not available, will raise standard_nosuchobject or other exception if raised by plugin loader.

        Parameters
        ----------
        aFormat: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<PCDM_Reader>

        """
        return _CDF.CDF_Application_ReaderFromFormat(self, *args)

    def Retrieve(self, *args) -> "opencascade::handle< CDM_Document >":
        r"""
        This method retrieves a document from the database. if the document references other documents which have been updated, the latest version of these documents will be used if {usestorageconfiguration} is standard_true. the content of {afolder}, {aname} and {aversion} depends on the database manager system. if the dbms is only based on the os, {afolder} is a directory and {aname} is the name of a file. in this case the use of the syntax with {aversion} has no sense. for example: //! opencascade::handle<cdm_document> thedocument=myapplication->retrieve('/home/cascade','box.dsg'); if the dbms is euclid/design manager, {afolder}, {aname} have the form they have in euclid/design manager. for example: //! opencascade::handle<cdm_document> thedocument=myapplication->retrieve('|user|cascade','box'); //! since the version is not specified in this syntax, the latest wil be used. a link is kept with the database through an instance of cdm_metadata.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        UseStorageConfiguration: bool,optional
        	default value is Standard_True
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<CDM_Document>
        This method retrieves a document from the database. if the document references other documents which have been updated, the latest version of these documents will be used if {usestorageconfiguration} is standard_true. -- if the dbms is only based on the os, this syntax should not be used. //! if the dbms is euclid/design manager, {afolder}, {aname} and {aversion} have the form they have in euclid/design manager. for example: //! opencascade::handle<cdm_document> thedocument=myapplication->retrieve('|user|cascade','box','2'); a link is kept with the database through an instance of cdm_metadata.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        aVersion: TCollection_ExtendedString
        UseStorageConfiguration: bool,optional
        	default value is Standard_True
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        opencascade::handle<CDM_Document>

        """
        return _CDF.CDF_Application_Retrieve(self, *args)

    def SetDefaultFolder(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aFolder: Standard_ExtString

        Returns
        -------
        bool

        """
        return _CDF.CDF_Application_SetDefaultFolder(self, *args)

    def WriterFromFormat(self, *args) -> "opencascade::handle< PCDM_StorageDriver >":
        r"""
        Returns instance of storage driver for specified format. //! default implementation uses plugin mechanism to load driver dynamically. for this to work, application resources should define guid of the plugin as value of [format].storageplugin, and 'plugin' resource should define name of plugin library to be loaded as value of [guid].location. plugin library should provide method pluginfactory returning instance of the reader for the same guid (see plugin_macro.hxx). //! in case if driver is not available, will raise standard_nosuchobject or other exception if raised by plugin loader.

        Parameters
        ----------
        aFormat: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<PCDM_StorageDriver>

        """
        return _CDF.CDF_Application_WriterFromFormat(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_CDF_Application_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_Application

# Register CDF_Application in _CDF:
_CDF.CDF_Application_swigregister(CDF_Application)

def CDF_Application_Load(*args) -> "opencascade::handle< CDF_Application >":
    r"""
    Plugs an application. //! open is used - for opening a document that has been created in an application - for opening a document from the database - for opening a document from a file. the open methods always add the document in the session directory and calls the virtual activate method. the document is considered to be opened until close is used. to be storable, a document must be opened by an application since the application resources are needed to store it.

    Parameters
    ----------
    aGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<CDF_Application>

    """
    return _CDF.CDF_Application_Load(*args)

class CDF_Directory(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty directory.

        Returns
        -------
        None

        """
        _CDF.CDF_Directory_swiginit(self, _CDF.new_CDF_Directory(*args))

    def Add(self, *args) -> "void":
        r"""
        Adds a document into the directory.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _CDF.CDF_Directory_Add(self, *args)

    def Contains(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the document adocument is in the directory.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        bool

        """
        return _CDF.CDF_Directory_Contains(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the directory is empty.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Directory_IsEmpty(self, *args)

    def Last(self, *args) -> "opencascade::handle< CDM_Document >":
        r"""
        Returns the last document (if any) which has been added in the directory.

        Returns
        -------
        opencascade::handle<CDM_Document>

        """
        return _CDF.CDF_Directory_Last(self, *args)

    def Length(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of documents of the directory.

        Returns
        -------
        int

        """
        return _CDF.CDF_Directory_Length(self, *args)

    def Remove(self, *args) -> "void":
        r"""
        Removes the document.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        return _CDF.CDF_Directory_Remove(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_CDF_Directory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_Directory

# Register CDF_Directory in _CDF:
_CDF.CDF_Directory_swigregister(CDF_Directory)

class CDF_MetaDataDriver(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def BuildFileName(self, *args) -> "TCollection_ExtendedString":
        r"""
        No available documentation.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        TCollection_ExtendedString

        """
        return _CDF.CDF_MetaDataDriver_BuildFileName(self, *args)

    def CreateDependsOn(self, *args) -> "void":
        r"""
        Creates a 'depends on' relation between two datas. by default does nothing.

        Parameters
        ----------
        aFirstData: CDM_MetaData
        aSecondData: CDM_MetaData

        Returns
        -------
        None

        """
        return _CDF.CDF_MetaDataDriver_CreateDependsOn(self, *args)

    def CreateMetaData(self, *args) -> "opencascade::handle< CDM_MetaData >":
        r"""
        Should create meta-data corresponding to adata and maintaining a meta-link between these meta-data and afilename createmetadata is called by createdata if the metadata-driver has version capabilities, version must be set in the returned data.

        Parameters
        ----------
        aDocument: CDM_Document
        aFileName: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<CDM_MetaData>

        """
        return _CDF.CDF_MetaDataDriver_CreateMetaData(self, *args)

    def CreateReference(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aFrom: CDM_MetaData
        aTo: CDM_MetaData
        aReferenceIdentifier: int
        aToDocumentVersion: int

        Returns
        -------
        None

        """
        return _CDF.CDF_MetaDataDriver_CreateReference(self, *args)

    def DefaultFolder(self, *args) -> "TCollection_ExtendedString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_ExtendedString

        """
        return _CDF.CDF_MetaDataDriver_DefaultFolder(self, *args)

    def Find(self, *args) -> "Standard_Boolean":
        r"""
        Should indicate whether meta-data exist in the dbms corresponding to the data. aversion may be null;.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        aVersion: TCollection_ExtendedString

        Returns
        -------
        bool
        Calls find with an empty version.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _CDF.CDF_MetaDataDriver_Find(self, *args)

    def FindFolder(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _CDF.CDF_MetaDataDriver_FindFolder(self, *args)

    def HasReadPermission(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        aVersion: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _CDF.CDF_MetaDataDriver_HasReadPermission(self, *args)

    def HasVersion(self, *args) -> "Standard_Boolean":
        r"""
        By default return standard_true.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString

        Returns
        -------
        bool

        """
        return _CDF.CDF_MetaDataDriver_HasVersion(self, *args)

    def HasVersionCapability(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the metadatadriver can manage different versions of a data. by default, returns standard_false.

        Returns
        -------
        bool

        """
        return _CDF.CDF_MetaDataDriver_HasVersionCapability(self, *args)

    def LastVersion(self, *args) -> "opencascade::handle< CDM_MetaData >":
        r"""
        By default returns ametadata should return the metadata stored in the dbms with the meta-data corresponding to the path. if the metadatadriver has version management capabilities the version has to be set in the returned metadata. metadata is called by getmetadata if the version is not included in the path , metadata should return the last version of the metadata is deferred;.

        Parameters
        ----------
        aMetaData: CDM_MetaData

        Returns
        -------
        opencascade::handle<CDM_MetaData>

        """
        return _CDF.CDF_MetaDataDriver_LastVersion(self, *args)

    def MetaData(self, *args) -> "opencascade::handle< CDM_MetaData >":
        r"""
        Should return the metadata stored in the dbms with the meta-data corresponding to the data. if the metadatadriver has version management capabilities the version has to be set in the returned metadata. aversion may be null metadata is called by getmetadata if the version is set to null, metadata should return the last version of the metadata.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString
        aVersion: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<CDM_MetaData>
        Calls metadata with an empty version.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString
        aName: TCollection_ExtendedString

        Returns
        -------
        opencascade::handle<CDM_MetaData>

        """
        return _CDF.CDF_MetaDataDriver_MetaData(self, *args)

    def ReferenceIterator(self, *args) -> "opencascade::handle< PCDM_ReferenceIterator >":
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        opencascade::handle<PCDM_ReferenceIterator>

        """
        return _CDF.CDF_MetaDataDriver_ReferenceIterator(self, *args)

    def SetName(self, *args) -> "TCollection_ExtendedString":
        r"""
        This methods is usefull if the name of an object -- depends on the metadatadriver. for example a driver -- based on the operating system can choose to add the extension of file to create to the object.

        Parameters
        ----------
        aDocument: CDM_Document
        aName: TCollection_ExtendedString

        Returns
        -------
        TCollection_ExtendedString

        """
        return _CDF.CDF_MetaDataDriver_SetName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_CDF_MetaDataDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_MetaDataDriver

# Register CDF_MetaDataDriver in _CDF:
_CDF.CDF_MetaDataDriver_swigregister(CDF_MetaDataDriver)

class CDF_MetaDataDriverFactory(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Build(self, *args) -> "opencascade::handle< CDF_MetaDataDriver >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<CDF_MetaDataDriver>

        """
        return _CDF.CDF_MetaDataDriverFactory_Build(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_CDF_MetaDataDriverFactory_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_MetaDataDriverFactory

# Register CDF_MetaDataDriverFactory in _CDF:
_CDF.CDF_MetaDataDriverFactory_swigregister(CDF_MetaDataDriverFactory)

class CDF_Store(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a store list from the document of the current selection.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        _CDF.CDF_Store_swiginit(self, _CDF.new_CDF_Store(*args))

    def AssociatedStatusText(self, *args) -> "Standard_ExtString":
        r"""
        No available documentation.

        Returns
        -------
        Standard_ExtString

        """
        return _CDF.CDF_Store_AssociatedStatusText(self, *args)

    def Comment(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_Comment(self, *args)

    def CurrentIsConsistent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_CurrentIsConsistent(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        Returns the description of the format of the main object.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_Description(self, *args)

    def Folder(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        Returns the folder in which the current document will be stored.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_Folder(self, *args)

    def HasAPreviousVersion(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_HasAPreviousVersion(self, *args)

    def IsConsistent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_IsConsistent(self, *args)

    def IsMainDocument(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the currentdocument is the main one, ie the document of the current selection.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_IsMainDocument(self, *args)

    def IsModified(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_IsModified(self, *args)

    def IsStored(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the current document is already stored.

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_IsStored(self, *args)

    def MetaDataPath(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        Returns the path of the previous store is the object is already stored, otherwise an empty string;.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_MetaDataPath(self, *args)

    def Name(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        Returns the name under which the current document will be stored.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_Name(self, *args)

    def Path(self, *args) -> "Standard_ExtString":
        r"""
        Returns the complete path of the created meta-data.

        Returns
        -------
        Standard_ExtString

        """
        return _CDF.CDF_Store_Path(self, *args)

    def PreviousVersion(self, *args) -> "opencascade::handle< TCollection_HExtendedString >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TCollection_HExtendedString>

        """
        return _CDF.CDF_Store_PreviousVersion(self, *args)

    def Realize(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _CDF.CDF_Store_Realize(self, *args)

    def RecheckName(self, *args) -> "CDF_StoreSetNameStatus":
        r"""
        Defines the name under which the document should be stored. uses for example after modification of the folder.

        Returns
        -------
        CDF_StoreSetNameStatus

        """
        return _CDF.CDF_Store_RecheckName(self, *args)

    def SetComment(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aComment: Standard_ExtString

        Returns
        -------
        None

        """
        return _CDF.CDF_Store_SetComment(self, *args)

    def SetCurrent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aPresentation: Standard_ExtString

        Returns
        -------
        None

        """
        return _CDF.CDF_Store_SetCurrent(self, *args)

    def SetFolder(self, *args) -> "Standard_Boolean":
        r"""
        Defines the folder in which the document should be stored. returns standard_true if the folder exists, standard_false otherwise.

        Parameters
        ----------
        aFolder: TCollection_ExtendedString

        Returns
        -------
        bool
        Defines the folder in which the document should be stored. returns standard_true if the folder exists, standard_false otherwise.

        Parameters
        ----------
        aFolder: Standard_ExtString

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_SetFolder(self, *args)

    def SetMain(self, *args) -> "void":
        r"""
        The two following methods can be used just after realize or import -- method to know if thes methods worked correctly, and if not why.

        Returns
        -------
        None

        """
        return _CDF.CDF_Store_SetMain(self, *args)

    def SetName(self, *args) -> "CDF_StoreSetNameStatus":
        r"""
        Defines the name under which the document should be stored.

        Parameters
        ----------
        aName: Standard_ExtString

        Returns
        -------
        CDF_StoreSetNameStatus
        Defines the name under which the document should be stored.

        Parameters
        ----------
        aName: TCollection_ExtendedString

        Returns
        -------
        CDF_StoreSetNameStatus

        """
        return _CDF.CDF_Store_SetName(self, *args)

    def SetPreviousVersion(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aPreviousVersion: Standard_ExtString

        Returns
        -------
        bool

        """
        return _CDF.CDF_Store_SetPreviousVersion(self, *args)

    def StoreStatus(self, *args) -> "PCDM_StoreStatus":
        r"""
        No available documentation.

        Returns
        -------
        PCDM_StoreStatus

        """
        return _CDF.CDF_Store_StoreStatus(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_Store

# Register CDF_Store in _CDF:
_CDF.CDF_Store_swigregister(CDF_Store)

class CDF_StoreList(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        aDocument: CDM_Document

        Returns
        -------
        None

        """
        _CDF.CDF_StoreList_swiginit(self, _CDF.new_CDF_StoreList(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _CDF.CDF_StoreList_Init(self, *args)

    def IsConsistent(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_StoreList_IsConsistent(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _CDF.CDF_StoreList_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _CDF.CDF_StoreList_Next(self, *args)

    def Store(self, *args) -> "PCDM_StoreStatus":
        r"""
        Stores each object of the storelist in the reverse order of which they had been added.

        Parameters
        ----------
        aMetaData: CDM_MetaData
        aStatusAssociatedText: TCollection_ExtendedString
        theRange: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        PCDM_StoreStatus

        """
        return _CDF.CDF_StoreList_Store(self, *args)

    def Value(self, *args) -> "opencascade::handle< CDM_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<CDM_Document>

        """
        return _CDF.CDF_StoreList_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_CDF_StoreList_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_StoreList

# Register CDF_StoreList in _CDF:
_CDF.CDF_StoreList_swigregister(CDF_StoreList)

class CDF_FWOSDriver(CDF_MetaDataDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the metadatadriver connected to specified look-up table. note that the created driver will keep reference to the table, thus it must have life time longer than this object.

        Parameters
        ----------
        theLookUpTable: CDM_MetaDataLookUpTable

        Returns
        -------
        None

        """
        _CDF.CDF_FWOSDriver_swiginit(self, _CDF.new_CDF_FWOSDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_CDF_FWOSDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _CDF.delete_CDF_FWOSDriver

# Register CDF_FWOSDriver in _CDF:
_CDF.CDF_FWOSDriver_swigregister(CDF_FWOSDriver)


@classnotwrapped
class CDF_DirectoryIterator:
	pass









##Copyright 2020 Thomas Paviot (tpaviot@gmail.com)
##
##This file is part of pythonOCC.
##
##pythonOCC is free software: you can redistribute it and/or modify
##it under the terms of the GNU Lesser General Public License as published by
##the Free Software Foundation, either version 3 of the License, or
##(at your option) any later version.
##
##pythonOCC is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##GNU Lesser General Public License for more details.
##
##You should have received a copy of the GNU Lesser General Public License
##along with pythonOCC.  If not, see <http://www.gnu.org/licenses/>.

__doc__ = """
handler for excluded classes and methods

Example of use
@methodnotwrapped
def foo(*kargs):
    pass

@classnotwrapped
class A:
    pass

This module is part of the OCC.Core package:
from OCC.Core.Exception import *
"""

class MethodNotWrappedError(BaseException):
    pass

class ClassNotWrappedError(BaseException):
    pass

def methodnotwrapped(func):
    def function_wrapper(*x):
        raise MethodNotWrappedError('%s not wrapped' % func.__name__)
    return function_wrapper

def classnotwrapped(klass):
    class NewCls(object):
        def __init__(self,*args,**kwargs):
            raise ClassNotWrappedError('%s not wrapped' % klass.__name__)
    return NewCls



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

MMgt_TShared = NewType('MMgt_TShared', Standard_Transient)

# harray1 classes
# harray2 classes
# hsequence classes

